.. _source:


.. raw:: html

     <br>

.. title:: Source


**genocide**

.. raw:: html

     <br>

.. autosummary::
    :toctree: 
    :template: base.rst

    genocide.bus	bus
    genocide.command	commands
    genocide.error	errors
    genocide.event	events
    genocide.json	decoder/encoder
    genocide.locks	locking
    genocide.object	clean namespace
    genocide.parser	parsing
    genocide.reactor	reacting
    genocide.repeater	repeating 
    genocide.thread	threading
    genocide.utils	utilities


**modules**

.. raw:: html

     <br>


.. autosummary::
    :toctree: 
    :template: base.rst

    genocide.modules.cmd	list of commands
    genocide.modules.dbg 	debug module
    genocide.modules.err	occured errors
    genocide.modules.flt	list of bots
    genocide.modules.irc	internet relay chat
    genocide.modules.log	log text
    genocide.modules.mdl	genocide model
    genocide.modules.req	request
    genocide.modules.rss	rich site syndicate
    genocide.modules.sts	status of bots
    genocide.modules.tdo   	todo list
    genocide.modules.udp	udp to irc relay
